import { validateSubfields } from 'sequelize-validate-subfields';
function checkPath(path) {
  for (const elem of path) {
    if (typeof elem !== 'string' && typeof elem !== 'symbol') {
      throw new Error(`invalid error path element: ${typeof elem}, ${String(elem)}`);
    }
  }
  return path;
}
export function* convertValidationErrors(validation, options = {}) {
  for (let error of validation.errors) {
    if (options.reduxFormStyle && error.expectedTypeAtPath.acceptsSomeCompositeTypes) {
      yield {
        path: [...checkPath(error.path), '_error'],
        message: error.messageAtPath()
      };
    } else yield {
      path: checkPath(error.path),
      message: error.messageAtPath()
    };
  }
}
export function validateWithTypedValidators(type, options = {}) {
  return validateSubfields(function* (value) {
    const validation = typeof type === 'function' ? type(value) : type.validate(value, undefined, []);
    if (validation) {
      yield* convertValidationErrors(validation, options);
    }
  });
}